@@ -153,7 +153,7 @@ class Bookmarks {
 	 * @param int $root Root folder from which to return hierarchy, -1 for absolute root
 	 * @return array the folders each in the format ["id" => int, "title" => string, "parent_folder" => int ]
 	 */
-	public function getFolderChildren($userId, $folderId = -1) {
+	public function getFolderChildren($userId, $folderId = -1, $layers=1) {
 		$qb = $this->db->getQueryBuilder();
 		$qb
 			->select('id', 'title', 'parent_folder', 'index')
@@ -175,10 +175,16 @@ class Bookmarks {
 
 		$children = array_merge($childFolders, $childBookmarks);
 		array_multisort(array_column($children, 'index'), \SORT_ASC, $children);
-		$children = array_map(function ($child) {
-			return isset($child['bookmark_id']) ?
-			  ['type' =>  'bookmark', 'id' => $child['bookmark_id']]
-			: ['type' => 'folder', 'id' => $child['id']];
+		$children = array_map(function ($child) use ($userId, $layers) {
+			return isset($child['bookmark_id'])
+			  ? ['type' =>  'bookmark', 'id' => $child['bookmark_id']]
+			  : ($layers === 1
+				  ? ['type' => 'folder', 'id' => $child['id']]
+					: [
+						 'type' => 'folder',
+					   'id' => $child['id'],
+						 'children' => $this->getFolderChildren($userId, $child['id'], $layers-1)
+					 ]);
 		}, $children);
 
 		return $children;
@@ -472,6 +478,12 @@ class Bookmarks {
 			} else {
 				unset($requestedAttributes[$key]);
 			}
+			$key = array_search('folders', $requestedAttributes);
+			if ($key === false) {
+				$returnFolders = false;
+			} else {
+				unset($requestedAttributes[$key]);
+			}
 			$selectedAttributes = array_intersect($tableAttributes, $requestedAttributes);
 			array_push($selectedAttributes, 'id');
 		} else {
@@ -812,7 +824,7 @@ class Bookmarks {
 	 * @param array $folders ids of the parent folders for the new bookmark
 	 * @return int The id of the bookmark created
 	 */
-	public function addBookmark($userid, $url, $title, $tags = [], $description = '', $isPublic = false, $folders = null) {
+	public function addBookmark($userid, $url, $title, $tags = [], $description = '', $isPublic = false, $folders = null, $date_added = null) {
 		$public = $isPublic ? 1 : 0;
 		if (!isset($folders) || count($folders) === 0) {
 			$folders = [-1]; // we have to do it this way, as we don't want people to add a bookmark with [] parents
@@ -820,34 +832,36 @@ class Bookmarks {
 
 		// do some meta tag inspection of the link...
 
-		// allow only http(s) and (s)ftp
-		$protocols = '/^(https?|s?ftp)\:\/\//i';
-		try {
-			if (preg_match($protocols, $url)) {
-				$data = $this->getURLMetadata($url);
-			} else {
-				// if no allowed protocol is given, evaluate https and https
-				foreach (['https://', 'http://'] as $protocol) {
-					$testUrl = $protocol . $url;
-					$data = $this->getURLMetadata($testUrl);
-					if (isset($data['basic']) && isset($data['basic']['title'])) {
-						break;
+		if (!isset($title)) {
+			// allow only http(s) and (s)ftp
+			$protocols = '/^(https?|s?ftp)\:\/\//i';
+			try {
+				if (preg_match($protocols, $url)) {
+					$data = $this->getURLMetadata($url);
+				} else {
+					// if no allowed protocol is given, evaluate https and https
+					foreach (['https://', 'http://'] as $protocol) {
+						$testUrl = $protocol . $url;
+						$data = $this->getURLMetadata($testUrl);
+						if (isset($data['basic']) && isset($data['basic']['title'])) {
+							break;
+						}
 					}
 				}
+			} catch (\Exception $e) {
+				// only because the server cannot reach a certain URL it does not
+				// mean the user's browser cannot.
+				\OC::$server->getLogger()->logException($e, ['app' => 'bookmarks']);
+			}
+			if (isset($data['url'])) {
+				$url = $data['url'];
+			}
+			if ((!isset($title) || trim($title) === '' && strlen($title) !== 0)) {
+				$title = isset($data['basic']) && isset($data['basic']['title'])? $data['basic']['title'] : $url;
+			}
+			if (isset($data['basic']['description']) && (!isset($description) || trim($description) === '')) {
+				$description = $data['basic']['description'];
 			}
-		} catch (\Exception $e) {
-			// only because the server cannot reach a certain URL it does not
-			// mean the user's browser cannot.
-			\OC::$server->getLogger()->logException($e, ['app' => 'bookmarks']);
-		}
-		if (isset($data['url'])) {
-			$url = $data['url'];
-		}
-		if ((!isset($title) || trim($title) === '')) {
-			$title = isset($data['basic']) && isset($data['basic']['title'])? $data['basic']['title'] : $url;
-		}
-		if (isset($data['basic']['description']) && (!isset($description) || trim($description) === '')) {
-			$description = $data['basic']['description'];
 		}
 
 		// Check if it is a valid URL (after adding http(s) prefix)
@@ -902,7 +916,7 @@ class Bookmarks {
 					'title' => $qb->createParameter('title'),
 					'user_id' => $qb->createParameter('user_id'),
 					'public' => $qb->createParameter('public'),
-					'added' => $qb->createFunction('UNIX_TIMESTAMP()'),
+					'added' => isset($date_added) ? $date_added : $qb->createFunction('UNIX_TIMESTAMP()'),
 					'lastmodified' => $qb->createFunction('UNIX_TIMESTAMP()'),
 					'description' => $qb->createParameter('description'),
 				])
@@ -1108,7 +1122,7 @@ class Bookmarks {
 		$folderId = $this->addFolder($userId, $folder['title'], $parentId);
 		foreach ($folder['bookmarks'] as $bookmark) {
 			try {
-				$this->addBookmark($userId, $bookmark['href'], $bookmark['title'], $bookmark['tags'], $bookmark['description'], false, [$folderId]);
+				$this->addBookmark($userId, $bookmark['href'], $bookmark['title'], $bookmark['tags'], $bookmark['description'], false, [$folderId], $bookmark['add_date']);
 			} catch (\InvalidArgumentException $e) {
 				$this->logger->logException($e, ['app' => 'bookmarks']);
 				$errors[] =  $this->l->t('Failed to import one bookmark, because: ') . $e->getMessage();
