@@ -196,7 +196,7 @@ class BookmarkController extends ApiController {
 		}
 
 		$attributesToSelect = ['url', 'title', 'id', 'user_id', 'description', 'public',
-			'added', 'lastmodified', 'clickcount', 'tags', 'image', 'favicon'];
+			'added', 'lastmodified', 'clickcount', 'tags', 'image', 'favicon', 'folders'];
 
 		$bookmarks = $this->bookmarks->findBookmarks(
 			$user,
@@ -226,8 +226,10 @@ class BookmarkController extends ApiController {
 	 * @NoCSRFRequired
 	 * @CORS
 	 */
-	public function newBookmark($url = "", $item = [], $title = "", $is_public = false, $description = "", $tags = [], $folders = null) {
-		$title = trim($title);
+	public function newBookmark($url = "", $item = [], $title = null, $is_public = false, $description = "", $tags = [], $folders = null) {
+		if (isset($title)) {
+			$title = trim($title);
+		}
 		if (count($tags) === 0) {
 			$tags = isset($item['tags']) ? $item['tags'] : [];
 		}
@@ -457,7 +459,7 @@ EOT;
 			$title = Util::sanitizeHTML($title);
 			$description = Util::sanitizeHTML($bookmark['description']);
 
-			$output .= '<DT><A HREF="' . $url . '" TAGS="' . $tags . '">' . $title . '</A>'."\n";
+			$output .= '<DT><A HREF="' . $url . '" TAGS="' . $tags . '" ADD_DATE="' . $bookmark['added']. '">' . $title . '</A>'."\n";
 			if (strlen($description)>0) {
 				$output .= '<DD>' . $description .'</DD>';
 			}
