@@ -6,17 +6,28 @@ OC.L10N.register(
     "No file provided for import" : "Няма избран файл за внасяне",
     "Unsupported file type for import" : "Типът на файла за внасяне не се поддържа",
     "Add a Bookmark" : "Добави отметка",
+    "Add folder" : "Добави папка",
+    "Select" : "Маркирай",
+    "Deselect" : "Размаркирай",
     "Details" : "Подробности",
+    "Delete" : "Изтрий",
+    "Date added" : "Дата на добавяне",
+    "Link" : "Връзка",
     "Tags" : "Етикети",
     "Description" : "Описание",
     "No bookmarks here." : "Тук няма отметки.",
+    "Favorites" : "Любими",
     "Settings" : "Настройки",
     "Bookmarklet" : "Скриптова отметка",
     "Recently added" : "Последно добавени",
+    "Most visited" : "Най-посещавани",
     "RSS Feed" : "RSS емисия",
+    "Delete all bookmarks" : "Изтрий всички отметки",
     "Error" : "Грешка",
-    "Import error" : "Грешка при внасяне",
+    "Uncategorized" : "Некатегоризирани",
     "Import completed successfully." : "Внасянето приключи успешно.",
+    "Do you really want to delete all your bookmarks?" : "Наистина ли желаете всички отметки да бъдат изтрити?",
+    "Set tags" : "Задайте етикет",
     "Add a bookmark" : "Добави отметка",
     "This URL is already bookmarked! Overwrite?" : "Този адрес е вече добавен към отметките! Искате ли да презапишете?",
     "The title of the page" : "Заглавието на страницата",
