@@ -28,8 +28,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Při pokusu o uložení záložky nastala chyba.",
     "Error" : "Chyba",
     "Uncategorized" : "Nezařazené",
-    "Import error" : "Import se nezdařil",
+    "Error parsing the import result" : "Chyba při analýze výsledku importu",
     "Import completed successfully." : "Import byl úspěšně dokončen",
+    "Do you really want to delete all your bookmarks?" : "Opravdu chcete smazat všechny své záložky?",
     "Set tags" : "Nastavit štítky",
     "A Bookmark manager for Nextcloud" : "Správce záložek pro Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Tato aplikace vám umožní ukládat a organizovat vaše oblíbené stránky na internetu a zároveň je synchronizuje přes vaše zařízení a prohlížeče. Mrkněte na neoficiální klienty: https://github.com/nextcloud/bookmarks#third-party-clients",
