@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Details",
     "Delete" : "Löschen",
     "Saved" : "Gespeichert",
+    "Date added" : "Datum hinzugefügt",
+    "Link" : "Link",
     "Tags" : "Schlagworte",
     "Description" : "Beschreibung",
     "No bookmarks here." : "Keine Lesezeichen vorhanden",
@@ -28,8 +30,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Beim Speichern des Lesezeichens ist ein Fehler aufgetreten.",
     "Error" : "Fehler",
     "Uncategorized" : "Ohne Kategorie",
-    "Import error" : "Fehler beim Import",
+    "Error parsing the import result" : "Fehler beim Analysieren des Importergebnisses",
     "Import completed successfully." : "Import erfolgreich beendet.",
+    "Do you really want to delete all your bookmarks?" : "Möchtest Du wirklich das Lesezeichen löschen?",
     "Set tags" : "Schlagworte setzen",
     "A Bookmark manager for Nextcloud" : "Eine Lesezeichenverwaltung für Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Diese App erlaubt es Ihnen all Ihre beliebten Orte im Internet an einer Stelle zu speichern und zu verwalten. Weiter werden diese Lesezeichen mit Ihren Geräten und Browsern synchronisiert.\nSehen Sie sich auch die Liste der Clients von Drittanbietern an: https://github.com/nextcloud/bookmarks#third-party-clients",
