@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Detalles",
     "Delete" : "Eliminar",
     "Saved" : "Guardado",
+    "Date added" : "Fecha en que se añadió",
+    "Link" : "Enlace",
     "Tags" : "Etiquetas",
     "Description" : "Descripción",
     "No bookmarks here." : "No hay marcadores aquí.",
@@ -28,8 +30,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Se ha producido un error al intentar guardar el marcador.",
     "Error" : "Error",
     "Uncategorized" : "Sin categoría",
-    "Import error" : "Error de importación",
+    "Error parsing the import result" : "Error al analizar el resultado de la importación",
     "Import completed successfully." : "Importación completada con éxito.",
+    "Do you really want to delete all your bookmarks?" : "¿Seguro que quieres eliminar todos tus marcadores?",
     "Set tags" : "Poner etiquetas",
     "A Bookmark manager for Nextcloud" : "Un gestor de marcadores para Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Esta app te permite almacenar y organizar tus lugares favoritos de la web en un solo lugar, permitiéndote sincronizarlos con varios dispositivos y navegadores.\nComprueba los clientes de terceras partes enumerados aquí: https://github.com/nextcloud/bookmarks#third-party-clients",
