@@ -26,8 +26,8 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Kirjanmerkin tallennusta yrittäessä tapahtui virhe.",
     "Error" : "Virhe",
     "Uncategorized" : "Luokittelematon",
-    "Import error" : "Tuontivirhe",
     "Import completed successfully." : "Tuonti suoritettiin onnistuneesti.",
+    "Do you really want to delete all your bookmarks?" : "Haluatko varmasti poistaa kaikki kirjanmerkkisi?",
     "Set tags" : "Aseta tunnisteet",
     "A Bookmark manager for Nextcloud" : "Kirjanmerkkien hallinta Nextcloudille",
     "Add a bookmark" : "Lisää kirjanmerkki",
