@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Propriétés",
     "Delete" : "Supprimer",
     "Saved" : "Sauvegardé",
+    "Date added" : "Date d'ajout",
+    "Link" : "Lien",
     "Tags" : "Étiquettes",
     "Description" : "Description",
     "No bookmarks here." : "Pas de favoris ici.",
@@ -28,8 +30,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Une erreur est survenue lors de la sauvegarde du marque-page.",
     "Error" : "Erreur",
     "Uncategorized" : "Non catégorisé",
-    "Import error" : "Erreur d'importation",
+    "Error parsing the import result" : "Erreur lors de l'analyse du résultat d'import",
     "Import completed successfully." : "Importation terminée avec succès.",
+    "Do you really want to delete all your bookmarks?" : "Voulez-vous réellement supprimer tous vos favoris ?",
     "Set tags" : "Choisir des étiquettes",
     "A Bookmark manager for Nextcloud" : "Un gestionnaire de favoris pour Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Cette application vous permet d'enregistrer et d'organiser vos sites favoris du web en un seul lieu, et vous permettre de les synchroniser avec vos différents appareils et navigateurs.\nConsultez la liste des clients tiers ici : https://github.com/nextcloud/bookmarks#third-party-clients",
