@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Dettagli",
     "Delete" : "Elimina",
     "Saved" : "Salvato",
+    "Date added" : "Data aggiunta",
+    "Link" : "Collegamento",
     "Tags" : "Etichette",
     "Description" : "Descrizione",
     "No bookmarks here." : "Qui non c'è alcun segnalibro",
@@ -28,8 +30,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Si è  verificato un errore durante il tentativo di salvataggio del segnalibro.",
     "Error" : "Errore",
     "Uncategorized" : "Senza categoria",
-    "Import error" : "Errore di importazione",
+    "Error parsing the import result" : "Errore durante l'elaborazione del risultato dell'importazione",
     "Import completed successfully." : "Importazione completata correttamente.",
+    "Do you really want to delete all your bookmarks?" : "Vuoi davvero eliminare tutti i tuoi segnalibri?",
     "Set tags" : "Imposta etichette",
     "A Bookmark manager for Nextcloud" : "Un gestore di segnalibri per Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Questa applicazione ti consente di archiviare e organizzare i tuoi siti preferiti sul web in un solo posto, mentre ti consente di sincronizzarli con i tuoi svariati dispositivi e browser.\nVerifica i client di terze parti elencati qui: https://github.com/nextcloud/bookmarks#third-party-clients",
