@@ -25,14 +25,14 @@ OC.L10N.register(
     "Permanently remove all bookmarks from your account. There is no going back!" : "アカウントからすべてのブックマークを完全に削除します。 戻ることはありません！",
     "Delete all bookmarks" : "すべてのブックマークを削除",
     "Open details" : "詳細を開く",
-    "An error occurred while trying to save the bookmark." : "ブックマークの保存を試している際にエラーが発生しました。",
+    "An error occurred while trying to save the bookmark." : "ブックマークの保存中にエラーが発生しました。",
     "Error" : "エラー",
     "Uncategorized" : "未分類",
-    "Import error" : "インポート エラー",
     "Import completed successfully." : "インポートに成功しました",
+    "Do you really want to delete all your bookmarks?" : "本当にすべてのブックマークを削除しますか？",
     "Set tags" : "タグを設定",
-    "A Bookmark manager for Nextcloud" : "Nextcloudのブックマークマネージャー",
-    "Add a bookmark" : "ブックマークへ追加",
+    "A Bookmark manager for Nextcloud" : "Nextcloud のブックマークマネージャー",
+    "Add a bookmark" : "ブックマークを追加",
     "This URL is already bookmarked! Overwrite?" : "このURLはすでにブックマークされています! 上書きしますか?",
     "The title of the page" : "ページのタイトル",
     "The address of the page" : "ページのアドレス",
