@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Detalhes",
     "Delete" : "Excluir",
     "Saved" : "Salvo",
+    "Date added" : "Data de adição",
+    "Link" : "Link",
     "Tags" : "Etiquetas",
     "Description" : "Descrição",
     "No bookmarks here." : "Não há marcadores aqui.",
@@ -28,8 +30,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Um erro ocorreu enquanto tentava salvar o favorito.",
     "Error" : "Erro",
     "Uncategorized" : "Não categorizado",
-    "Import error" : "Erro na importação",
+    "Error parsing the import result" : "Erro ao analisar o resultado da importação",
     "Import completed successfully." : "Importação finalizada com sucesso.",
+    "Do you really want to delete all your bookmarks?" : "Deseja realmente excluir todos os favoritos?",
     "Set tags" : "Atribuir tags",
     "A Bookmark manager for Nextcloud" : "Um gerenciador de marcadores para o Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Este aplicativo permite que você armazene e organize seus lugares favoritos na Web em um único local, ao mesmo tempo em que permite sincronizá-los com vários dispositivos e navegadores.\nConfira os clientes de terceiros listados aqui: https://github.com/nextcloud/bookmarks#third-party-clients",
