@@ -28,8 +28,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Дошло је до грешке при покушају чувања забелешке.",
     "Error" : "Грешка",
     "Uncategorized" : "Некатегоризовано",
-    "Import error" : "Грешка приликом увоза",
+    "Error parsing the import result" : "Грешка при парсирању резултата увоза",
     "Import completed successfully." : "Увоз успешно завршен.",
+    "Do you really want to delete all your bookmarks?" : "Да ли стварно желите да избришете све Ваше белешке?",
     "Set tags" : "Постави ознаке",
     "A Bookmark manager for Nextcloud" : "Менаџер забелешки за Некстклауд",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Ова апликација Вам омогућава да складиштите и организујете Ваша омиљена места на интернету на једном месту, док у исто време можете да их синхронизујете са разним уређајима и веб читачима.\nПогледајте клијенте треће стране излистане овде: https://github.com/nextcloud/bookmarks#third-party-clients",
