@@ -6,6 +6,7 @@ OC.L10N.register(
     "No file provided for import" : "Inga filer given för importering",
     "Unsupported file type for import" : "Ogiltig filtyp för import",
     "Add a Bookmark" : "Lägg till ett bokmärke",
+    "Add folder" : "Lägg till mapp",
     "Select" : "Välj",
     "Deselect" : "Välj inte",
     "Details" : "Detaljer",
@@ -14,6 +15,7 @@ OC.L10N.register(
     "Tags" : "Taggar",
     "Description" : "Beskrivning",
     "No bookmarks here." : "Inga bokmärken här.",
+    "Favorites" : "Favoriter",
     "Settings" : "Inställningar",
     "Add to {instanceName} " : "Lägg till {instanceName} ",
     "Recently added" : "Nyligen tillagd",
@@ -24,8 +26,9 @@ OC.L10N.register(
     "Open details" : "Öppna detaljer",
     "An error occurred while trying to save the bookmark." : "Ett fel uppstod när bokmärket skulle sparas.",
     "Error" : "Fel",
-    "Import error" : "Importeringsfel",
+    "Uncategorized" : "Okategoriserad",
     "Import completed successfully." : "Importen slutfördes utan problem.",
+    "Do you really want to delete all your bookmarks?" : "Vill du verkligen radera alla dina bokmärken?",
     "Set tags" : "Ange taggar",
     "A Bookmark manager for Nextcloud" : "En bokmärkeshanterare för Nextcloud",
     "Add a bookmark" : "Lägg till ett bokmärke",
