@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Ayrıntılar",
     "Delete" : "Sil",
     "Saved" : "Kaydedildi",
+    "Date added" : "Eklendiği tarih",
+    "Link" : "Bağlantı",
     "Tags" : "İşaretler",
     "Description" : "Açıklama",
     "No bookmarks here." : "Henüz bir yer imi yok.",
@@ -28,8 +30,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Yer imi kaydedilmeye çalışılırken bir sorun çıktı.",
     "Error" : "Hata",
     "Uncategorized" : "Kategorisiz",
-    "Import error" : "İçe aktarma sorunu",
+    "Error parsing the import result" : "İçe aktarma sonuçları işlenirken sorun çıktı",
     "Import completed successfully." : "İçe aktarma tamamlandı.",
+    "Do you really want to delete all your bookmarks?" : "Tüm yer imlerinizi silmek istediğinize emin misiniz?",
     "Set tags" : "Etiketleri ayarla",
     "A Bookmark manager for Nextcloud" : "Nextcloud için yer imi yöneticisi",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Bu uygulama İnternet üzerinde sık ziyaret ettiğiniz konumları bir noktada toplamanızı ve farklı aygıt ve tarayıcılar ile eşitlemenizi sağlar.\nÜçüncü taraf istemcileri şurada görebilirsiniz: https://github.com/nextcloud/bookmarks#third-party-clients",
